#
#         Simulation of
#       Two Moving Bodies
#
import numpy as np
import pygame as pg
import sys

pg.init()
screen = pg.display.set_mode(size=(800,700))
screen.fill((0, 0, 0))
pg.display.flip()

def x_scale(x):
    return 400 + x * 100

def y_scale(y):
    return 350 + y * 100
#
#       The initial values
#
x0 = np.array([3.0, 0.0])
x1 = np.array([0.0,0.0])
v0h = np.array([0.0, -0.8])
v1h = np.array([0.0, 0.1])

d_t = 0.001

while True:
    #
    #     Calculation of values for update
    #
    x0_t = x0 + d_t * v0h
    x1_t = x1 + d_t * v1h
    r2 = np.sum((x0_t - x1_t)**2)
    v0h_t = v0h + d_t * (-8) * (x0_t - x1_t) / (r2**(3/2))
    v1h_t = v1h + d_t * (x0_t - x1_t) / (r2**(3/2))
    #
    #        Update the values
    #    cf. Feynman et al. (1963), p. 9-6.
    #
    x0 = x0_t
    x1 = x1_t
    v0h = v0h_t
    v1h = v1h_t
    #
    #        Display the updated values
    #        
    screen.fill((0, 0, 0))
    pg.draw.circle(screen, (255, 200,255), (x_scale(x0[0]), y_scale(x0[1])), 5)
    pg.draw.circle(screen, (0, 255, 255), (x_scale(x1[0]), y_scale(x1[1])), 20)
    pg.display.flip()

    for e in pg.event.get():
        if e.type == pg.QUIT:    #   Is the windows's close button clicked?
            pg.quit()
            sys.exit()

    pg.time.wait(1)

